import React, { type ReactNode, type KeyboardEvent, type FocusEventHandler } from 'react';
import { FilterMatchEnum, MenuPositionEnum } from './constants';
import { type DefaultTheme } from 'styled-components';
import type { OptionData, PartialDeep, IconRenderer, FocusedOption, SelectedOption, CallbackFn, AriaLiveAttribute, OptionLabelCallback, OptionValueCallback } from './types';
export declare type Theme = PartialDeep<DefaultTheme>;
export declare type MultiParams = Readonly<{
    selected: SelectedOption[];
    renderOptionLabel: (data: OptionData) => ReactNode;
}>;
export declare type MenuOption = Readonly<{
    label: string | number;
    value: string | number;
    data: OptionData;
    isDisabled: boolean;
    isSelected: boolean;
}>;
export declare type SelectRef = Readonly<{
    empty: boolean;
    menuOpen: boolean;
    blur: () => void;
    focus: () => void;
    clearValue: () => void;
    toggleMenu: (state?: boolean) => void;
    setValue: (option?: OptionData) => void;
}>;
export declare type SelectProps = Readonly<{
    async?: boolean;
    inputId?: string;
    selectId?: string;
    isMulti?: boolean;
    ariaLabel?: string;
    required?: boolean;
    loadingMsg?: string;
    autoFocus?: boolean;
    isLoading?: boolean;
    isInvalid?: boolean;
    inputDelay?: number;
    themeConfig?: Theme;
    isDisabled?: boolean;
    placeholder?: string;
    menuItemSize?: number;
    isClearable?: boolean;
    memoOptions?: boolean;
    lazyLoadMenu?: boolean;
    options?: OptionData[];
    isSearchable?: boolean;
    menuMaxHeight?: number;
    loadingNode?: ReactNode;
    ariaLabelledBy?: string;
    clearIcon?: IconRenderer;
    caretIcon?: IconRenderer;
    openMenuOnClick?: boolean;
    openMenuOnFocus?: boolean;
    menuPortalTarget?: Element;
    menuOverscanCount?: number;
    tabSelectsOption?: boolean;
    filterIgnoreCase?: boolean;
    menuScrollDuration?: number;
    blurInputOnSelect?: boolean;
    closeMenuOnSelect?: boolean;
    isAriaLiveEnabled?: boolean;
    menuWidth?: string | number;
    scrollMenuIntoView?: boolean;
    noOptionsMsg?: string | null;
    ariaLive?: AriaLiveAttribute;
    hideSelectedOptions?: boolean;
    filterIgnoreAccents?: boolean;
    onMenuOpen?: CallbackFn;
    onMenuClose?: CallbackFn;
    backspaceClearsValue?: boolean;
    menuPosition?: MenuPositionEnum;
    filterMatchFrom?: FilterMatchEnum;
    menuItemDirection?: 'ltr' | 'rtl';
    itemKeySelector?: string | number;
    getOptionLabel?: OptionLabelCallback;
    getOptionValue?: OptionValueCallback;
    initialValue?: OptionData | OptionData[];
    onInputChange?: (value?: string) => unknown;
    onSearchChange?: (value?: string) => unknown;
    onOptionChange?: (data: OptionData) => unknown;
    onInputBlur?: FocusEventHandler<HTMLInputElement>;
    onInputFocus?: FocusEventHandler<HTMLInputElement>;
    renderOptionLabel?: (data: OptionData) => ReactNode;
    getIsOptionDisabled?: (data: OptionData) => boolean;
    getFilterOptionString?: (option: MenuOption) => string;
    renderMultiOptions?: (params: MultiParams) => ReactNode;
    onKeyDown?: (e: KeyboardEvent<Element>, input?: string, focusedOption?: FocusedOption) => unknown;
}>;
declare const Select: React.ForwardRefExoticComponent<Readonly<{
    async?: boolean | undefined;
    inputId?: string | undefined;
    selectId?: string | undefined;
    isMulti?: boolean | undefined;
    ariaLabel?: string | undefined;
    required?: boolean | undefined;
    loadingMsg?: string | undefined;
    autoFocus?: boolean | undefined;
    isLoading?: boolean | undefined;
    isInvalid?: boolean | undefined;
    inputDelay?: number | undefined;
    themeConfig?: PartialDeep<DefaultTheme> | undefined;
    isDisabled?: boolean | undefined;
    placeholder?: string | undefined;
    menuItemSize?: number | undefined;
    isClearable?: boolean | undefined;
    memoOptions?: boolean | undefined;
    lazyLoadMenu?: boolean | undefined;
    options?: any[] | undefined;
    isSearchable?: boolean | undefined;
    menuMaxHeight?: number | undefined;
    loadingNode?: ReactNode;
    ariaLabelledBy?: string | undefined;
    clearIcon?: IconRenderer;
    caretIcon?: IconRenderer;
    openMenuOnClick?: boolean | undefined;
    openMenuOnFocus?: boolean | undefined;
    menuPortalTarget?: Element | undefined;
    menuOverscanCount?: number | undefined;
    tabSelectsOption?: boolean | undefined;
    filterIgnoreCase?: boolean | undefined;
    menuScrollDuration?: number | undefined;
    blurInputOnSelect?: boolean | undefined;
    closeMenuOnSelect?: boolean | undefined;
    isAriaLiveEnabled?: boolean | undefined;
    menuWidth?: string | number | undefined;
    scrollMenuIntoView?: boolean | undefined;
    noOptionsMsg?: string | null | undefined;
    ariaLive?: AriaLiveAttribute | undefined;
    hideSelectedOptions?: boolean | undefined;
    filterIgnoreAccents?: boolean | undefined;
    onMenuOpen?: CallbackFn | undefined;
    onMenuClose?: CallbackFn | undefined;
    backspaceClearsValue?: boolean | undefined;
    menuPosition?: MenuPositionEnum | undefined;
    filterMatchFrom?: FilterMatchEnum | undefined;
    menuItemDirection?: "ltr" | "rtl" | undefined;
    itemKeySelector?: string | number | undefined;
    getOptionLabel?: OptionValueCallback | undefined;
    getOptionValue?: OptionValueCallback | undefined;
    initialValue?: OptionData | OptionData[];
    onInputChange?: ((value?: string) => unknown) | undefined;
    onSearchChange?: ((value?: string) => unknown) | undefined;
    onOptionChange?: ((data: OptionData) => unknown) | undefined;
    onInputBlur?: React.FocusEventHandler<HTMLInputElement> | undefined;
    onInputFocus?: React.FocusEventHandler<HTMLInputElement> | undefined;
    renderOptionLabel?: ((data: OptionData) => ReactNode) | undefined;
    getIsOptionDisabled?: ((data: OptionData) => boolean) | undefined;
    getFilterOptionString?: ((option: MenuOption) => string) | undefined;
    renderMultiOptions?: ((params: MultiParams) => ReactNode) | undefined;
    onKeyDown?: ((e: KeyboardEvent<Element>, input?: string, focusedOption?: FocusedOption) => unknown) | undefined;
}> & React.RefAttributes<Readonly<{
    empty: boolean;
    menuOpen: boolean;
    blur: () => void;
    focus: () => void;
    clearValue: () => void;
    toggleMenu: (state?: boolean) => void;
    setValue: (option?: OptionData) => void;
}>>>;
export default Select;
